Option<T> class
sealed
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isNone(
) → bool -
isSome(
) → bool -
map<
T2> (Option< T2> f(T)) → Option<T2> -
mapOr<
T2> (Option< T2> f(T), T2 or) → Option<T2> -
mapOrElse<
T2> (Option< T2> f(T), T2 orElse()) → Option<T2> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
or(
Option< T> other) → Option<T> -
orElse(
Option< T> other()) → Option<T> -
toString(
) → String -
A string representation of this object.
inherited
-
unwrap(
) → T -
unwrapOr(
T or) → T -
unwrapOrElse(
T orElse()) → T
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited